##############
Widget classes
##############

.. automodule:: pymeasure.display.widgets.browser_widget
    :members:
    :show-inheritance:

.. automodule:: pymeasure.display.widgets.directory_widget
    :members:
    :show-inheritance:

.. automodule:: pymeasure.display.widgets.estimator_widget
    :members:
    :show-inheritance:

.. automodule:: pymeasure.display.widgets.fileinput_widget
    :members:
    :show-inheritance:

.. automodule:: pymeasure.display.widgets.filename_widget
    :members:
    :show-inheritance:

.. automodule:: pymeasure.display.widgets.image_frame
    :members:
    :show-inheritance:

.. automodule:: pymeasure.display.widgets.image_widget
    :members:
    :show-inheritance:

.. automodule:: pymeasure.display.widgets.inputs_widget
    :members:
    :show-inheritance:

.. automodule:: pymeasure.display.widgets.log_widget
    :members:
    :show-inheritance:

.. automodule:: pymeasure.display.widgets.plot_frame
    :members:
    :show-inheritance:

.. automodule:: pymeasure.display.widgets.plot_widget
    :members:
    :show-inheritance:

.. automodule:: pymeasure.display.widgets.results_dialog
    :members:
    :show-inheritance:

.. automodule:: pymeasure.display.widgets.sequencer_widget
    :members:
    :show-inheritance:

.. automodule:: pymeasure.display.widgets.tab_widget
    :members:
    :show-inheritance:

.. automodule:: pymeasure.display.widgets.dock_widget
    :members:
    :show-inheritance:

.. automodule:: pymeasure.display.widgets.table_widget
    :members:
    :show-inheritance:
